Small wrapper for asuswrt.

Help neede for tests, just open a PR!

### How to run tests

`python setup.py test`

## Credits:
[@mvn23](https://github.com/mvn23)
[@halkeye](https://github.com/halkeye)
[@maweki](https://github.com/maweki)
